summaryrefslogtreecommitdiffstats
path: root/karbon/core
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /karbon/core
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'karbon/core')
-rw-r--r--karbon/core/vclipgroup.cc2
-rw-r--r--karbon/core/vclipgroup.h2
-rw-r--r--karbon/core/vcomposite.cc4
-rw-r--r--karbon/core/vcomposite.h2
-rw-r--r--karbon/core/vcursor.cc6
-rw-r--r--karbon/core/vcursor.h4
-rw-r--r--karbon/core/vfill.cc8
-rw-r--r--karbon/core/vfill.h2
-rw-r--r--karbon/core/vgradient.cc6
-rw-r--r--karbon/core/vgradient.h2
-rw-r--r--karbon/core/vgroup.cc4
-rw-r--r--karbon/core/vgroup.h6
-rw-r--r--karbon/core/vimage.cc2
-rw-r--r--karbon/core/vimage.h2
-rw-r--r--karbon/core/vkarbonplugin.cc2
-rw-r--r--karbon/core/vkarbonplugin.h2
-rw-r--r--karbon/core/vlayer.cc4
-rw-r--r--karbon/core/vlayer.h6
-rw-r--r--karbon/core/vobject.cc14
-rw-r--r--karbon/core/vobject.h24
-rw-r--r--karbon/core/vobject_iface.cc6
-rw-r--r--karbon/core/vobject_iface.h4
-rw-r--r--karbon/core/vpath.cc6
-rw-r--r--karbon/core/vpath.h2
-rw-r--r--karbon/core/vselection.cc10
-rw-r--r--karbon/core/vselection.h6
-rw-r--r--karbon/core/vstroke.cc16
-rw-r--r--karbon/core/vstroke.h8
-rw-r--r--karbon/core/vtext.cc6
-rw-r--r--karbon/core/vtext.h2
30 files changed, 85 insertions, 85 deletions
diff --git a/karbon/core/vclipgroup.cc b/karbon/core/vclipgroup.cc
index 2451f321..9a36c1c5 100644
--- a/karbon/core/vclipgroup.cc
+++ b/karbon/core/vclipgroup.cc
@@ -32,7 +32,7 @@
#include "vsegment.h"
#include <vpainter.h>
#include "vtext.h"
-VClipGroup::VClipGroup( VObject* tqparent, VState state ) : VGroup( tqparent, state ) {}
+VClipGroup::VClipGroup( VObject* parent, VState state ) : VGroup( parent, state ) {}
VClipGroup::VClipGroup( const VClipGroup& group ) : VGroup( group ) {}
VClipGroup::~VClipGroup() { }
diff --git a/karbon/core/vclipgroup.h b/karbon/core/vclipgroup.h
index f53055c6..683c3b61 100644
--- a/karbon/core/vclipgroup.h
+++ b/karbon/core/vclipgroup.h
@@ -33,7 +33,7 @@ class VPainter;
class KARBONBASE_EXPORT VClipGroup : public VGroup
{
public:
- VClipGroup( VObject* tqparent, VState state = normal );
+ VClipGroup( VObject* parent, VState state = normal );
VClipGroup ( const VClipGroup& group );
virtual ~VClipGroup();
diff --git a/karbon/core/vcomposite.cc b/karbon/core/vcomposite.cc
index 7872df5f..570b06dc 100644
--- a/karbon/core/vcomposite.cc
+++ b/karbon/core/vcomposite.cc
@@ -44,8 +44,8 @@
#include <kdebug.h>
-VPath::VPath( VObject* tqparent, VState state )
- : VObject( tqparent, state ), m_fillRule( winding )
+VPath::VPath( VObject* parent, VState state )
+ : VObject( parent, state ), m_fillRule( winding )
{
m_paths.setAutoDelete( true );
diff --git a/karbon/core/vcomposite.h b/karbon/core/vcomposite.h
index bcac57dd..c1f6e87f 100644
--- a/karbon/core/vcomposite.h
+++ b/karbon/core/vcomposite.h
@@ -47,7 +47,7 @@ typedef TQPtrListIterator<VSubpath> VSubpathListIterator;
class KARBONBASE_EXPORT VPath : public VObject, SVGPathParser
{
public:
- VPath( VObject* tqparent, VState state = normal );
+ VPath( VObject* parent, VState state = normal );
VPath( const VPath& path );
virtual ~VPath();
diff --git a/karbon/core/vfill.h b/karbon/core/vfill.h
index d05b8c88..0e562949 100644
--- a/karbon/core/vfill.h
+++ b/karbon/core/vfill.h
@@ -72,7 +72,7 @@ public:
void save( TQDomElement& element ) const;
void saveOasis( KoGenStyles &mainStyles, KoGenStyle &style ) const;
void load( const TQDomElement& element );
- void loadOasis( const TQDomElement &object, KoOasisLoadingContext &context, VObject* tqparent = 0L );
+ void loadOasis( const TQDomElement &object, KoOasisLoadingContext &context, VObject* parent = 0L );
VFill& operator=( const VFill& fill );
diff --git a/karbon/core/vgradient.cc b/karbon/core/vgradient.cc
index 11d6239f..60d89241 100644
--- a/karbon/core/vgradient.cc
+++ b/karbon/core/vgradient.cc
@@ -221,15 +221,15 @@ VGradient::saveOasis( KoGenStyles &mainStyles ) const
}
void
-VGradient::loadOasis( const TQDomElement &object, KoStyleStack &/*stack*/, VObject* tqparent )
+VGradient::loadOasis( const TQDomElement &object, KoStyleStack &/*stack*/, VObject* parent )
{
kdDebug(38000) << "namespaceURI: " << object.namespaceURI() << endl;
kdDebug(38000) << "localName: " << object.localName() << endl;
KoRect bb;
- if( tqparent )
- bb = tqparent->boundingBox();
+ if( parent )
+ bb = parent->boundingBox();
if( object.namespaceURI() == KoXmlNS::draw && object.localName() == "gradient" )
{
diff --git a/karbon/core/vgradient.h b/karbon/core/vgradient.h
index 8341eeab..12b9d552 100644
--- a/karbon/core/vgradient.h
+++ b/karbon/core/vgradient.h
@@ -109,7 +109,7 @@ public:
void save( TQDomElement& element ) const;
TQString saveOasis( KoGenStyles &mainStyles ) const;
void load( const TQDomElement& element );
- void loadOasis( const TQDomElement &object, KoStyleStack &stack, VObject* tqparent = 0L );
+ void loadOasis( const TQDomElement &object, KoStyleStack &stack, VObject* parent = 0L );
void transform( const TQWMatrix& m );
diff --git a/karbon/core/vgroup.cc b/karbon/core/vgroup.cc
index 35f3991e..51d991e1 100644
--- a/karbon/core/vgroup.cc
+++ b/karbon/core/vgroup.cc
@@ -51,8 +51,8 @@
#include <kdebug.h>
-VGroup::VGroup( VObject* tqparent, VState state )
- : VObject( tqparent, state )
+VGroup::VGroup( VObject* parent, VState state )
+ : VObject( parent, state )
{
m_stroke = new VStroke( this );
m_fill = new VFill();
diff --git a/karbon/core/vimage.cc b/karbon/core/vimage.cc
index 7f75254b..4e846661 100644
--- a/karbon/core/vimage.cc
+++ b/karbon/core/vimage.cc
@@ -17,7 +17,7 @@
#include <kdebug.h>
-VImage::VImage( VObject *tqparent, const TQString &fname ) : VObject( tqparent ), m_image( 0L ), m_fname( fname )
+VImage::VImage( VObject *parent, const TQString &fname ) : VObject( parent ), m_image( 0L ), m_fname( fname )
{
m_stroke = new VStroke( this );
m_stroke->setType( VStroke::none );
diff --git a/karbon/core/vimage.h b/karbon/core/vimage.h
index 2933b4eb..531c2bf5 100644
--- a/karbon/core/vimage.h
+++ b/karbon/core/vimage.h
@@ -14,7 +14,7 @@ class TQImage;
class KARBONBASE_EXPORT VImage : public VObject
{
public:
- VImage( VObject *tqparent, const TQString &fname = "" );
+ VImage( VObject *parent, const TQString &fname = "" );
VImage( const VImage & );
virtual ~VImage();
diff --git a/karbon/core/vkarbonplugin.cc b/karbon/core/vkarbonplugin.cc
index d05043d9..41fd47a8 100644
--- a/karbon/core/vkarbonplugin.cc
+++ b/karbon/core/vkarbonplugin.cc
@@ -19,7 +19,7 @@
#include "vkarbonplugin.h"
-VKarbonPlugin::VKarbonPlugin( TQObject *tqparent, const char* name ) : Plugin( tqparent, name )
+VKarbonPlugin::VKarbonPlugin( TQObject *parent, const char* name ) : Plugin( parent, name )
{
}
diff --git a/karbon/core/vkarbonplugin.h b/karbon/core/vkarbonplugin.h
index e86680a0..84fed9c6 100644
--- a/karbon/core/vkarbonplugin.h
+++ b/karbon/core/vkarbonplugin.h
@@ -26,7 +26,7 @@
class KARBONBASE_EXPORT VKarbonPlugin : public KParts::Plugin
{
public:
- VKarbonPlugin( TQObject *tqparent, const char* name );
+ VKarbonPlugin( TQObject *parent, const char* name );
virtual ~VKarbonPlugin() {}
};
diff --git a/karbon/core/vlayer.cc b/karbon/core/vlayer.cc
index dddfe6ce..47fe919d 100644
--- a/karbon/core/vlayer.cc
+++ b/karbon/core/vlayer.cc
@@ -35,8 +35,8 @@
#include "vfill.h"
#include "vstroke.h"
-VLayer::VLayer( VObject* tqparent, VState state )
- : VGroup( tqparent, state )
+VLayer::VLayer( VObject* parent, VState state )
+ : VGroup( parent, state )
{
setName( "Layer" );
// HACK : vlayer just shouldn't have fill/stroke at all
diff --git a/karbon/core/vobject.cc b/karbon/core/vobject.cc
index 5e9f74b6..897652c3 100644
--- a/karbon/core/vobject.cc
+++ b/karbon/core/vobject.cc
@@ -33,12 +33,12 @@
#include <KoOasisLoadingContext.h>
#include <KoOasisStyles.h>
-VObject::VObject( VObject* tqparent, VState state ) : m_dcop( 0L )
+VObject::VObject( VObject* parent, VState state ) : m_dcop( 0L )
{
m_stroke = 0L;
m_fill = 0L;
- m_parent = tqparent;
+ m_parent = parent;
m_state = state;
invalidateBoundingBox();
@@ -205,9 +205,9 @@ VObject::addStyles( const TQDomElement* style, KoOasisLoadingContext & context )
{
if(style)
{
- // this function is necessary as tqparent styles can have parents themself
- if( style->hasAttributeNS( KoXmlNS::style, "tqparent-style-name" ) )
- addStyles( context.oasisStyles().findStyle( style->attributeNS( KoXmlNS::style, "tqparent-style-name", TQString() ) ), context );
+ // this function is necessary as parent styles can have parents themself
+ if( style->hasAttributeNS( KoXmlNS::style, "parent-style-name" ) )
+ addStyles( context.oasisStyles().findStyle( style->attributeNS( KoXmlNS::style, "parent-style-name", TQString() ) ), context );
context.addStyles( style, "style-name" );
}
}
@@ -216,8 +216,8 @@ VDocument *
VObject::document() const
{
VObject *obj = (VObject *)this;
- while( obj->tqparent() )
- obj = obj->tqparent();
+ while( obj->parent() )
+ obj = obj->parent();
return dynamic_cast<VDocument *>( obj );
}
diff --git a/karbon/core/vobject.h b/karbon/core/vobject.h
index 7cbbb0e9..899422ee 100644
--- a/karbon/core/vobject.h
+++ b/karbon/core/vobject.h
@@ -44,7 +44,7 @@ class KoGenStyle;
* have the ability to draw itself using a painter, perform
* hit detection, transform on demand, clone and load/save itself.
* Also each object manages its own bounding box and keeps track of its
- * tqparent object.
+ * parent object.
*/
class KARBONBASE_EXPORT VObject
{
@@ -63,16 +63,16 @@ public:
};
/**
- * Constructs a new object that is child of tqparent and has the given state.
+ * Constructs a new object that is child of parent and has the given state.
*
- * @param tqparent the new object's tqparent
+ * @param parent the new object's parent
* @param state the new object's state
*/
- VObject( VObject* tqparent, VState state = edit );
+ VObject( VObject* parent, VState state = edit );
/**
* Copy constructor.
- * Copies tqparent, state and name of given object.
+ * Copies parent, state and name of given object.
*
* @param obj the object to copy properties from
*/
@@ -133,18 +133,18 @@ public:
}
/**
- * Sets a new tqparent object.
+ * Sets a new parent object.
*
- * @param tqparent the new tqparent object
+ * @param parent the new parent object
*/
- void setParent( VObject* tqparent ) { m_parent = tqparent; }
+ void setParent( VObject* parent ) { m_parent = parent; }
/**
- * Returns pointer to current tqparent object.
+ * Returns pointer to current parent object.
*
- * @return pointer to current tqparent object or 0 if no tqparent object is set
+ * @return pointer to current parent object or 0 if no parent object is set
*/
- VObject* tqparent() const { return m_parent; }
+ VObject* parent() const { return m_parent; }
/**
* Get the state the object is in.
@@ -266,7 +266,7 @@ public:
/**
* Return document the object belongs to.
*
- * @return pointer to tqparent document or 0 if object does not belong to a document
+ * @return pointer to parent document or 0 if object does not belong to a document
*/
VDocument *document() const;
diff --git a/karbon/core/vobject_iface.cc b/karbon/core/vobject_iface.cc
index 09291ec4..c93b68d6 100644
--- a/karbon/core/vobject_iface.cc
+++ b/karbon/core/vobject_iface.cc
@@ -41,11 +41,11 @@ VObjectIface::setState( int state )
}
DCOPRef
-VObjectIface::tqparent() const
+VObjectIface::parent() const
{
- if( !m_object->tqparent() )
+ if( !m_object->parent() )
return DCOPRef();
- return DCOPRef( kapp->dcopClient()->appId(), m_object->tqparent()->dcopObject()->objId() );
+ return DCOPRef( kapp->dcopClient()->appId(), m_object->parent()->dcopObject()->objId() );
}
diff --git a/karbon/core/vobject_iface.h b/karbon/core/vobject_iface.h
index e3a081d3..bbf2c6c5 100644
--- a/karbon/core/vobject_iface.h
+++ b/karbon/core/vobject_iface.h
@@ -45,9 +45,9 @@ k_dcop:
bool boundingBoxIsInvalid() const;
void invalidateBoundingBox();
- void setParent( VObject* tqparent ) { m_parent = tqparent; }*/
+ void setParent( VObject* parent ) { m_parent = parent; }*/
- DCOPRef tqparent() const;
+ DCOPRef parent() const;
int state() const;
void setState( int state );
diff --git a/karbon/core/vpath.cc b/karbon/core/vpath.cc
index 1442d90c..e5366966 100644
--- a/karbon/core/vpath.cc
+++ b/karbon/core/vpath.cc
@@ -125,8 +125,8 @@ private:
};
-VSubpath::VSubpath( VObject* tqparent )
- : VObject( tqparent )
+VSubpath::VSubpath( VObject* parent )
+ : VObject( parent )
{
m_isClosed = false;
@@ -654,7 +654,7 @@ VSubpath::revert()
return;
- VSubpath list( tqparent() );
+ VSubpath list( parent() );
list.moveTo( getLast()->knot() );
VSegment* segment = getLast();
diff --git a/karbon/core/vpath.h b/karbon/core/vpath.h
index 48c89a4c..7ed6f9be 100644
--- a/karbon/core/vpath.h
+++ b/karbon/core/vpath.h
@@ -44,7 +44,7 @@ class KARBONBASE_EXPORT VSubpath : public VObject
friend class VSubpathIterator;
public:
- VSubpath( VObject* tqparent );
+ VSubpath( VObject* parent );
VSubpath( const VSubpath& list );
VSubpath( const VSegment& segment );
virtual ~VSubpath();
diff --git a/karbon/core/vselection.cc b/karbon/core/vselection.cc
index 77809ac5..5a10373f 100644
--- a/karbon/core/vselection.cc
+++ b/karbon/core/vselection.cc
@@ -32,8 +32,8 @@
uint VSelection::m_handleNodeSize = 3;
-VSelection::VSelection( VObject* tqparent )
- : VObject( tqparent ), m_showhandle( true )
+VSelection::VSelection( VObject* parent )
+ : VObject( parent ), m_showhandle( true )
{
m_handleRect = new KoRect[ 10 ];
setStroke( VStroke( VColor( TQt::black ) ) );
@@ -90,7 +90,7 @@ VSelection::take( const KoRect& rect, bool selectObjects, bool exclusive )
if( selectObjects )
{
VSelectObjects op( m_objects, rect, false );
- if( op.visit( *static_cast<VDocument*>( tqparent() ) ) )
+ if( op.visit( *static_cast<VDocument*>( parent() ) ) )
{
selectNodes();
success = true;
@@ -123,7 +123,7 @@ VSelection::append()
clear();
VSelectObjects op( m_objects );
- op.visit( *static_cast<VDocument*>( tqparent() ) );
+ op.visit( *static_cast<VDocument*>( parent() ) );
selectNodes();
invalidateBoundingBox();
@@ -159,7 +159,7 @@ VSelection::append( const KoRect& rect, bool selectObjects, bool exclusive )
{
//m_objects.clear();
VSelectObjects op( m_objects, rect );
- if( op.visit( *static_cast<VDocument*>( tqparent() ) ) )
+ if( op.visit( *static_cast<VDocument*>( parent() ) ) )
{
selectNodes();
success = true;
diff --git a/karbon/core/vstroke.cc b/karbon/core/vstroke.cc
index 043f4e27..0ec27fb2 100644
--- a/karbon/core/vstroke.cc
+++ b/karbon/core/vstroke.cc
@@ -33,10 +33,10 @@ VStroke::VStroke()
: m_parent(0L), m_lineWidth(1.0), m_lineCap(capButt), m_lineJoin(joinMiter), m_miterLimit(10.0), m_type(none)
{}
-VStroke::VStroke( VObject* tqparent, float width, const VLineCap cap, const VLineJoin join,
+VStroke::VStroke( VObject* parent, float width, const VLineCap cap, const VLineJoin join,
float miterLimit )
{
- m_parent = tqparent;
+ m_parent = parent;
m_type = solid;
m_lineWidth = width;
m_lineCap = cap;
@@ -44,10 +44,10 @@ VStroke::VStroke( VObject* tqparent, float width, const VLineCap cap, const VLin
m_miterLimit = miterLimit;
}
-VStroke::VStroke( const VColor &c, VObject* tqparent, float width, const VLineCap cap, const VLineJoin join,
+VStroke::VStroke( const VColor &c, VObject* parent, float width, const VLineCap cap, const VLineJoin join,
float miterLimit )
{
- m_parent = tqparent;
+ m_parent = parent;
m_type = solid;
m_lineWidth = width;
m_lineCap = cap;
@@ -58,7 +58,7 @@ VStroke::VStroke( const VColor &c, VObject* tqparent, float width, const VLineCa
VStroke::VStroke( const VStroke& stroke )
{
- // doesn't copy tqparent:
+ // doesn't copy parent:
*this = stroke;
}
@@ -67,7 +67,7 @@ VStroke::setLineWidth( float width )
{
m_lineWidth = width;
- // tell our tqparent so he can update his bbox:
+ // tell our parent so he can update his bbox:
if( m_parent )
m_parent->invalidateBoundingBox();
}
@@ -235,11 +235,11 @@ VStroke::operator=( const VStroke& stroke )
{
if( this != &stroke )
{
- // dont copy the tqparent!
+ // dont copy the parent!
m_type = stroke.m_type;
m_lineWidth = stroke.m_lineWidth;
- // Tell our tqparent about the linewidth change, so he can update his bbox:
+ // Tell our parent about the linewidth change, so he can update his bbox:
//if( m_parent )
// m_parent->invalidateBoundingBox();
diff --git a/karbon/core/vstroke.h b/karbon/core/vstroke.h
index 90eedc43..5be1eaf4 100644
--- a/karbon/core/vstroke.h
+++ b/karbon/core/vstroke.h
@@ -72,14 +72,14 @@ public:
};
VStroke();
- VStroke( VObject* tqparent, float width = 1.0, const VLineCap cap = capButt,
+ VStroke( VObject* parent, float width = 1.0, const VLineCap cap = capButt,
const VLineJoin join = joinMiter, float miterLimit = 10.0 );
- VStroke( const VColor &c, VObject* tqparent = 0L, float width = 1.0, const VLineCap cap = capButt,
+ VStroke( const VColor &c, VObject* parent = 0L, float width = 1.0, const VLineCap cap = capButt,
const VLineJoin join = joinMiter, float miterLimit = 10.0 );
VStroke( const VStroke& stroke );
- void setParent( VObject* tqparent ) { m_parent = tqparent; }
- VObject* tqparent()const { return m_parent; }
+ void setParent( VObject* parent ) { m_parent = parent; }
+ VObject* parent()const { return m_parent; }
VStrokeType type() const { return m_type; }
void setType( VStrokeType type ) { m_type = type; }
diff --git a/karbon/core/vtext.cc b/karbon/core/vtext.cc
index e73445ee..c45d91cb 100644
--- a/karbon/core/vtext.cc
+++ b/karbon/core/vtext.cc
@@ -120,8 +120,8 @@ FT_Outline_Funcs OutlineMethods =
#endif // HAVE_KARBONTEXT
-VText::VText( VObject* tqparent, VState state )
- : VObject( tqparent, state ), m_basePath( 0L )
+VText::VText( VObject* parent, VState state )
+ : VObject( parent, state ), m_basePath( 0L )
{
m_glyphs.setAutoDelete( true );
m_boundingBoxIsInvalid = true;
@@ -287,7 +287,7 @@ VText::clone() const
VGroup* VText::toVGroup() const
{
- VGroup* group = new VGroup( tqparent() );
+ VGroup* group = new VGroup( parent() );
VPathListIterator itr( m_glyphs );
for( itr.toFirst(); itr.current(); ++itr )
diff --git a/karbon/core/vtext.h b/karbon/core/vtext.h
index 55455c5f..ef40ac28 100644
--- a/karbon/core/vtext.h
+++ b/karbon/core/vtext.h
@@ -56,7 +56,7 @@ public:
Right
};
- VText( VObject* tqparent, VState state = normal );
+ VText( VObject* parent, VState state = normal );
VText( const TQFont &font, const VSubpath& basePath, Position position, Alignment tqalignment, const TQString& text );
VText( const VText& text );
virtual ~VText();
diff --git a/karbon/core/vcursor.cc b/karbon/core/vcursor.cc
index a44004f2..c5fb2f40 100644
--- a/karbon/core/vcursor.cc
+++ b/karbon/core/vcursor.cc
@@ -92,13 +92,13 @@ TQCursor VCursor::createCursor( CursorType type )
}
}
-TQCursor VCursor::createCursor( const char * bitmap[], const char * tqmask[], int hotX, int hotY )
+TQCursor VCursor::createCursor( const char * bitmap[], const char * mask[], int hotX, int hotY )
{
// the cursor bitmap and tqmask
TQBitmap b, m;
b = TQPixmap( (const char**) bitmap );
- m = TQPixmap( (const char**) tqmask );
+ m = TQPixmap( (const char**) mask );
return TQCursor( b, m, hotX, hotY );
}
@@ -92,13 +92,13 @@ TQCursor VCursor::createCursor( CursorType type )
{
- // the cursor bitmap and tqmask
+ // the cursor bitmap and mask
TQBitmap b, m;
b = TQPixmap( (const char**) bitmap );
diff --git a/karbon/core/vcursor.h b/karbon/core/vcursor.h
index 90ab1673..ccb4a36f 100644
--- a/karbon/core/vcursor.h
+++ b/karbon/core/vcursor.h
@@ -27,7 +27,7 @@
* A helper class for easily creating cursors from XPMs.
*
* One can create a predefined unthemed cursor or create a cursor from two given XMPs,
* the cursor bitmap and the cursor tqmask.
*/
class KARBONBASE_EXPORT VCursor
{
@@ -53,7 +53,7 @@ public:
* Creates a cursor from two specified XPM images.
* This is only a wrapper function for a TQCursor ctor.
*/
- static TQCursor createCursor( const char * bitmap[], const char * tqmask[], int hotX = -1, int hotY = -1 );
+ static TQCursor createCursor( const char * bitmap[], const char * mask[], int hotX = -1, int hotY = -1 );
/** crosshair cursor */
static TQCursor crossHair();
@@ -27,7 +27,7 @@
*
* One can create a predefined unthemed cursor or create a cursor from two given XMPs,
-* the cursor bitmap and the cursor tqmask.
+* the cursor bitmap and the cursor mask.
*/
class KARBONBASE_EXPORT VCursor
diff --git a/karbon/core/vfill.cc b/karbon/core/vfill.cc
index 549045ae..d1cd9d13 100644
--- a/karbon/core/vfill.cc
+++ b/karbon/core/vfill.cc
@@ -48,7 +48,7 @@ VFill::VFill( const VColor &c )
VFill::VFill( const VFill& fill )
{
- // doesn't copy tqparent:
+ // doesn't copy parent:
*this = fill;
}
@@ -100,7 +100,7 @@ VFill::saveOasis( KoGenStyles &mainStyles, KoGenStyle &style ) const
}
void
-VFill::loadOasis( const TQDomElement &/*object*/, KoOasisLoadingContext &context, VObject* tqparent )
+VFill::loadOasis( const TQDomElement &/*object*/, KoOasisLoadingContext &context, VObject* parent )
{
KoStyleStack &stack = context.styleStack();
if( stack.hasAttributeNS( KoXmlNS::draw, "fill" ) )
@@ -118,7 +118,7 @@ VFill::loadOasis( const TQDomElement &/*object*/, KoOasisLoadingContext &context
TQDomElement *grad = context.oasisStyles().drawStyles()[ style ];
kdDebug()<<" style gradient name :"<< grad <<endl;
if( grad )
- m_gradient.loadOasis( *grad, stack, tqparent );
+ m_gradient.loadOasis( *grad, stack, parent );
}
if( stack.hasAttributeNS( KoXmlNS::draw, "opacity" ) )
m_color.setOpacity( stack.attributeNS( KoXmlNS::draw, "opacity" ).remove( '%' ).toFloat() / 100. );
@@ -161,7 +161,7 @@ VFill::operator=( const VFill& fill )
{
if( this != &fill )
{
// dont copy the tqparent!
m_type = fill.m_type;
m_color = fill.m_color;
m_gradient = fill.m_gradient;
@@ -161,7 +161,7 @@ VFill::operator=( const VFill& fill )
if( this != &fill )
{
- // dont copy the tqparent!
+ // dont copy the parent!
m_type = fill.m_type;
m_color = fill.m_color;
diff --git a/karbon/core/vgroup.h b/karbon/core/vgroup.h
index 29eb3842..dbb3d326 100644
--- a/karbon/core/vgroup.h
+++ b/karbon/core/vgroup.h
@@ -35,14 +35,14 @@ class KARBONBASE_EXPORT VGroup : public VObject
{
public:
/**
* Constructs a new group object that is child of tqparent and has the given state.
*
* The object's fill and stroke are created here.
*
* @param tqparent the new object's tqparent
* @param state the new object's state
*/
- VGroup( VObject* tqparent, VState state = normal );
+ VGroup( VObject* parent, VState state = normal );
/**
* Copy constructor.
@@ -35,14 +35,14 @@ class KARBONBASE_EXPORT VGroup : public VObject
public:
/**
- * Constructs a new group object that is child of tqparent and has the given state.
+ * Constructs a new group object that is child of parent and has the given state.
*
* The object's fill and stroke are created here.
@@ -35,14 +35,14 @@ class KARBONBASE_EXPORT VGroup : public VObject
* The object's fill and stroke are created here.
*
- * @param tqparent the new object's tqparent
+ * @param parent the new object's parent
* @param state the new object's state
*/
diff --git a/karbon/core/vlayer.h b/karbon/core/vlayer.h
index 7dbd126b..f52e7be4 100644
--- a/karbon/core/vlayer.h
+++ b/karbon/core/vlayer.h
@@ -37,12 +37,12 @@ class KARBONBASE_EXPORT VLayer : public VGroup
{
public:
/**
* Constructs a new layer object that is child of tqparent and has the given state.
*
* @param tqparent the new object's tqparent
* @param state the new object's state
*/
- VLayer( VObject* tqparent, VState state = normal );
+ VLayer( VObject* parent, VState state = normal );
/**
* Copy constructor.
@@ -37,12 +37,12 @@ class KARBONBASE_EXPORT VLayer : public VGroup
public:
/**
- * Constructs a new layer object that is child of tqparent and has the given state.
+ * Constructs a new layer object that is child of parent and has the given state.
*
@@ -37,12 +37,12 @@ class KARBONBASE_EXPORT VLayer : public VGroup
*
- * @param tqparent the new object's tqparent
+ * @param parent the new object's parent
* @param state the new object's state
*/
diff --git a/karbon/core/vselection.h b/karbon/core/vselection.h
index c98e5bf1..3db5d539 100644
--- a/karbon/core/vselection.h
+++ b/karbon/core/vselection.h
@@ -62,11 +62,11 @@ class KARBONBASE_EXPORT VSelection : public VObject, public VVisitor
{
public:
/**
* Constructs a vselection with the specified tqparent.
*
* @param tqparent the selection's tqparent
*/
- VSelection( VObject* tqparent = 0L );
+ VSelection( VObject* parent = 0L );
/**
* Constructs a vselection by copying the specified selection.
@@ -62,11 +62,11 @@ class KARBONBASE_EXPORT VSelection : public VObject, public VVisitor
public:
/**
- * Constructs a vselection with the specified tqparent.
+ * Constructs a vselection with the specified parent.
*
@@ -62,11 +62,11 @@ class KARBONBASE_EXPORT VSelection : public VObject, public VVisitor
*
- * @param tqparent the selection's tqparent
+ * @param parent the selection's parent
*/